@@ -614,6 +614,7 @@ def dsfr_tag(*args, **kwargs) -> dict:
     data_dict = {
         "label": "Label of the tag",
         "link": "(Optional) link of the tag",
+        "onclick": "(Optional) action that happens when the tag is clicked on",
         "extra_classes: (Optional) string with names of extra classes"
     }
 
@@ -629,7 +630,7 @@ def dsfr_tag(*args, **kwargs) -> dict:
         {% dsfr_highlight data_dict %}
     """
 
-    allowed_keys = ["label", "link", "extra_classes"]
+    allowed_keys = ["label", "link", "onclick", "extra_classes"]
     tag_data = parse_tag_args(args, kwargs, allowed_keys)
 
     return {"self": tag_data}
